"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.create_result200_response_all_of import CreateResult200ResponseAllOf
from qaseio.model.create_result200_response_all_of_result import CreateResult200ResponseAllOfResult
from qaseio.model.response import Response
globals()['CreateResult200ResponseAllOf'] = CreateResult200ResponseAllOf
globals()['CreateResult200ResponseAllOfResult'] = CreateResult200ResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.create_result200_response import CreateResult200Response


class TestCreateResult200Response(unittest.TestCase):
    """CreateResult200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateResult200Response(self):
        """Test CreateResult200Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateResult200Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
