"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.custom_field_value import CustomFieldValue
from qaseio.model.run_environment import RunEnvironment
from qaseio.model.run_milestone import RunMilestone
from qaseio.model.run_stats import RunStats
from qaseio.model.tag_value import TagValue
globals()['CustomFieldValue'] = CustomFieldValue
globals()['RunEnvironment'] = RunEnvironment
globals()['RunMilestone'] = RunMilestone
globals()['RunStats'] = RunStats
globals()['TagValue'] = TagValue
from qaseio.model.run import Run


class TestRun(unittest.TestCase):
    """Run unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRun(self):
        """Test Run"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Run()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
