"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.milestone import Milestone
from qaseio.model.milestone_response_all_of import MilestoneResponseAllOf
from qaseio.model.response import Response
globals()['Milestone'] = Milestone
globals()['MilestoneResponseAllOf'] = MilestoneResponseAllOf
globals()['Response'] = Response
from qaseio.model.milestone_response import MilestoneResponse


class TestMilestoneResponse(unittest.TestCase):
    """MilestoneResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMilestoneResponse(self):
        """Test MilestoneResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MilestoneResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
