"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.author import Author
from qaseio.model.author_response_all_of import AuthorResponseAllOf
from qaseio.model.response import Response
globals()['Author'] = Author
globals()['AuthorResponseAllOf'] = AuthorResponseAllOf
globals()['Response'] = Response
from qaseio.model.author_response import AuthorResponse


class TestAuthorResponse(unittest.TestCase):
    """AuthorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorResponse(self):
        """Test AuthorResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthorResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
