"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.author_list_response_all_of import AuthorListResponseAllOf
from qaseio.model.author_list_response_all_of_result import AuthorListResponseAllOfResult
from qaseio.model.response import Response
globals()['AuthorListResponseAllOf'] = AuthorListResponseAllOf
globals()['AuthorListResponseAllOfResult'] = AuthorListResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.author_list_response import AuthorListResponse


class TestAuthorListResponse(unittest.TestCase):
    """AuthorListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAuthorListResponse(self):
        """Test AuthorListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AuthorListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
