"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.milestone_list_response_all_of import MilestoneListResponseAllOf
from qaseio.model.milestone_list_response_all_of_result import MilestoneListResponseAllOfResult
from qaseio.model.response import Response
globals()['MilestoneListResponseAllOf'] = MilestoneListResponseAllOf
globals()['MilestoneListResponseAllOfResult'] = MilestoneListResponseAllOfResult
globals()['Response'] = Response
from qaseio.model.milestone_list_response import MilestoneListResponse


class TestMilestoneListResponse(unittest.TestCase):
    """MilestoneListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMilestoneListResponse(self):
        """Test MilestoneListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MilestoneListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
