"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import qaseio
from qaseio.api.result_api import ResultApi  # noqa: E501


class TestResultApi(unittest.TestCase):
    """ResultApi unit test stubs"""

    def setUp(self):
        self.api = ResultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_results_v2(self):
        """Test case for create_results_v2

        """
        pass


if __name__ == '__main__':
    unittest.main()
