"""
    Qase.io API

    Qase API Specification.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import qaseio
from qaseio.model.result_attachment import ResultAttachment
from qaseio.model.result_execution import ResultExecution
from qaseio.model.result_relations import ResultRelations
from qaseio.model.result_step import ResultStep
globals()['ResultAttachment'] = ResultAttachment
globals()['ResultExecution'] = ResultExecution
globals()['ResultRelations'] = ResultRelations
globals()['ResultStep'] = ResultStep
from qaseio.model.create_results_request_v2_results_inner import CreateResultsRequestV2ResultsInner


class TestCreateResultsRequestV2ResultsInner(unittest.TestCase):
    """CreateResultsRequestV2ResultsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateResultsRequestV2ResultsInner(self):
        """Test CreateResultsRequestV2ResultsInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateResultsRequestV2ResultsInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
